--[[---------------------------------------------------------------------------
    Addon:  TargetClassName
    File:   TargetClassName.lua
    Desc:   This file contains the core implementation for this addon.
-----------------------------------------------------------------------------]]

--:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
--[[                        Constants                                        ]]
--:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

kAddonName = ...
kAddonVersion = (GetAddOnMetadata(kAddonName, "Version") or "0.0.0.0"):match("^([%d.]+)")

--:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
--[[                        Variables                                        ]]
--:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

local AddonFrame = CreateFrame("Frame")

--:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
--[[                        Event Handler                                    ]]
--:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

-------------------------------------------------------------------------------
AddonFrame:RegisterEvent("ADDON_LOADED")
AddonFrame:RegisterEvent("UNIT_FACTION")
AddonFrame:RegisterEvent("PLAYER_TARGET_CHANGED")
AddonFrame:RegisterEvent("GROUP_ROSTER_UPDATE")
-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - --
AddonFrame:SetScript("OnEvent", function(thisFrame, event, ...)
    if (event == "ADDON_LOADED") then
        local addonName = ...
        if (addonName == kAddonName) then
            print("|c7f7f7fff".. kAddonName .." "..kAddonVersion.." loaded.|r") -- Color format = xRGB.
            AddonFrame:onLoad()
            AddonFrame:UnregisterEvent("ADDON_LOADED")
        end
    else
        AddonFrame:updateText()
    end
end)

--:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
--[[                            Functions                                    ]]
--:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

----------------------------------------------------- --------------------------
function AddonFrame:onLoad()
    if not AddonFrame.classNameFrame then
        local width, height = 104, 22
        local parent = TargetFrame
        
        local f = CreateFrame("frame", kAddonName.."Frame", parent, "BackdropTemplate")
        f:SetSize(width, height)
        f:SetPoint("CENTER", parent, "TOPLEFT", (width/2)+106, -3)
        ----f:SetFrameStrata( parent:GetFrameStrata() )
        f:SetFrameLevel( parent:GetFrameLevel()+1 )
        
        f:SetBackdrop({
            bgFile = "Interface\\Tooltips\\UI-Tooltip-Background",
            edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
            tile = true, tileSize = 16, edgeSize = 16,
            insets = { left = 4, right = 4, top = 2, bottom = 2, },
        })
        f:SetBackdropColor(0,0,1, 0.5)
        ----f:SetBackdropBorderColor(r,g,b, a)

        -- Create class name font.
        f.text = f:CreateFontString(nil, "ARTWORK", "GameFontNormal")
        f.text:SetPoint("CENTER", f, "CENTER", 2, 0)
        f.text:SetJustifyH("CENTER")
        
        AddonFrame.classNameFrame = f
        AddonFrame:updateText()
    end
end

-------------------------------------------------------------------------------
function AddonFrame:updateText()
    if not UnitExists("target") then return end
    ----print("C:", UnitClass("target"), "  B:", UnitClassBase("target"), "  T:", UnitCreatureType("target"))

    local theText
    if UnitIsPlayer("target") then
        ----local friendlySpecID, friendlySpecName = GetSpecializationInfoByID( GetInspectSpecialization("target") )
        theText = UnitClass("target") or ""
    else
        local className = UnitClassBase("target")
        if className ~= nil then className = className.." npc" end
        theText = className or UnitCreatureType("target") or ""
    end
    
    ----print(theText)
    AddonFrame.classNameFrame.text:SetText(theText)
end

--- End of File ---